@@ -1,21 +1,26 @@
+from __future__ import absolute_import
 import re
 import requests
 from bs4 import BeautifulSoup
-from amazon_scraper import review_url, reviews_url, extract_review_id, dict_acceptable, retry
+from amazon_scraper import review_url, reviews_url, extract_review_id, dict_acceptable, retry, rate_limit, extract_reviews_id, user_agent
 
 
 class Reviews(object):
-    def __init__(self, ItemId=None, URL=None):
+    def __init__(self, api, ItemId=None, URL=None):
         if ItemId and not URL:
             # check for http://www.amazon.com
             if 'amazon' in ItemId:
                 raise ValueError('URL passed as ASIN')
 
             URL = reviews_url(ItemId)
-
+        else:
+            if URL:
+                # cleanup the url
+                URL = reviews_url(extract_reviews_id(URL))                
         if not URL:
             raise ValueError('Invalid review page parameters')
 
+        self.api = api
         self._URL = URL
         self._soup = None
 
@@ -23,9 +28,14 @@ class Reviews(object):
     @retry()
     def soup(self):
         if not self._soup:
-            r = requests.get(self._URL)
+            rate_limit(self.api)
+            r = requests.get(self._URL, headers={'User-Agent':user_agent}, verify=False)
             r.raise_for_status()
-            self._soup = BeautifulSoup(r.text, 'html.parser')
+            # fix #1
+            # 'html.parser' has trouble with http://www.amazon.com/product-reviews/B00008MOQA/ref=cm_cr_pr_top_sort_recent?&sortBy=bySubmissionDateDescending
+            # it sometimes doesn't find the asin span
+            #self._soup = BeautifulSoup(r.text, 'html.parser')
+            self._soup = BeautifulSoup(r.text, 'html5lib')
         return self._soup
 
     def __iter__(self):
